@@ -17,15 +17,15 @@ import logging
 
 from sushy import exceptions
 from sushy.resources import base
-from sushy.resources.chassis import mappings as cha_maps
+from sushy.resources.chassis import constants as cha_cons
 from sushy.resources.chassis.power import power
 from sushy.resources.chassis.thermal import thermal
 from sushy.resources import common
+from sushy.resources import constants as res_cons
 from sushy.resources.manager import manager
-from sushy.resources import mappings as res_maps
+from sushy.resources.system.network import adapter
 from sushy import utils
 
-
 LOG = logging.getLogger(__name__)
 
 
@@ -35,7 +35,7 @@ class ActionsField(base.CompositeField):
 
 class PhysicalSecurity(base.CompositeField):
     intrusion_sensor = base.MappedField('IntrusionSensor',
-                                        cha_maps.CHASSIS_INTRUSION_SENSOR_MAP)
+                                        cha_cons.IntrusionSensor)
     """IntrusionSensor
     This indicates the known state of the physical security sensor, such as if
     it is hardware intrusion detected.
@@ -44,9 +44,8 @@ class PhysicalSecurity(base.CompositeField):
     intrusion_sensor_number = base.Field('IntrusionSensorNumber')
     """A numerical identifier to represent the physical security sensor"""
 
-    intrusion_sensor_re_arm = (
-        base.MappedField('IntrusionSensorReArm',
-                         cha_maps.CHASSIS_INTRUSION_SENSOR_RE_ARM_MAP))
+    intrusion_sensor_re_arm = base.MappedField('IntrusionSensorReArm',
+                                               cha_cons.IntrusionSensorReArm)
     """This indicates how the Normal state to be restored"""
 
 
@@ -58,8 +57,7 @@ class Chassis(base.ResourceBase):
     such as racks, enclosures, chassis and all other containers.
     """
 
-    chassis_type = base.MappedField('ChassisType',
-                                    cha_maps.CHASSIS_TYPE_VALUE_MAP,
+    chassis_type = base.MappedField('ChassisType', cha_cons.ChassisType,
                                     required=True)
     """The type of physical form factor of the chassis"""
 
@@ -89,8 +87,7 @@ class Chassis(base.ResourceBase):
     manufacturer.
     """
 
-    indicator_led = base.MappedField('IndicatorLED',
-                                     res_maps.INDICATOR_LED_VALUE_MAP)
+    indicator_led = base.MappedField('IndicatorLED', res_cons.IndicatorLED)
     """The state of the indicator LED, used to identify the chassis"""
 
     manufacturer = base.Field('Manufacturer')
@@ -108,8 +105,7 @@ class Chassis(base.ResourceBase):
     security.
     """
 
-    power_state = base.MappedField('PowerState',
-                                   res_maps.POWER_STATE_VALUE_MAP)
+    power_state = base.MappedField('PowerState', res_cons.PowerState)
     """The current power state of the chassis"""
 
     serial_number = base.Field('SerialNumber')
@@ -145,7 +141,7 @@ class Chassis(base.ResourceBase):
     _actions = ActionsField('Actions')
 
     def __init__(self, connector, identity, redfish_version=None,
-                 registries=None):
+                 registries=None, root=None):
         """A class representing a Chassis
 
         :param connector: A Connector instance
@@ -154,9 +150,11 @@ class Chassis(base.ResourceBase):
             the object according to schema of the given version.
         :param registries: Dict of Redfish Message Registry objects to be
             used in any resource that needs registries to parse messages
+        :param root: Sushy root object. Empty for Sushy root itself.
         """
         super(Chassis, self).__init__(
-            connector, identity, redfish_version, registries)
+            connector, identity, redfish_version=redfish_version,
+            registries=registries, root=root)
 
     def _get_reset_action_element(self):
         reset_action = self._actions.reset
@@ -178,11 +176,10 @@ class Chassis(base.ResourceBase):
         if not reset_action.allowed_values:
             LOG.warning('Could not figure out the allowed values for the '
                         'reset chassis action for Chassis %s', self.identity)
-            return set(res_maps.RESET_TYPE_VALUE_MAP_REV)
+            return set(res_cons.ResetType)
 
-        return set([res_maps.RESET_TYPE_VALUE_MAP[v] for v in
-                    set(res_maps.RESET_TYPE_VALUE_MAP).
-                    intersection(reset_action.allowed_values)])
+        return {v for v in res_cons.ResetType
+                if v.value in reset_action.allowed_values}
 
     def reset_chassis(self, value):
         """Reset the chassis.
@@ -196,7 +193,7 @@ class Chassis(base.ResourceBase):
             raise exceptions.InvalidParameterValueError(
                 parameter='value', value=value, valid_values=valid_resets)
 
-        value = res_maps.RESET_TYPE_VALUE_MAP_REV[value]
+        value = res_cons.ResetType(value).value
         target_uri = self._get_reset_action_element().target_uri
 
         LOG.debug('Resetting the Chassis %s ...', self.identity)
@@ -206,19 +203,18 @@ class Chassis(base.ResourceBase):
     def set_indicator_led(self, state):
         """Set IndicatorLED to the given state.
 
-        :param state: Desired LED state, lit (INDICATOR_LED_LIT), blinking
-            (INDICATOR_LED_BLINKING), off (INDICATOR_LED_OFF)
+        :param state: Desired LED state, an IndicatorLED value.
         :raises: InvalidParameterValueError, if any information passed is
             invalid.
         """
-        if state not in res_maps.INDICATOR_LED_VALUE_MAP_REV:
+        try:
+            state = res_cons.IndicatorLED(state).value
+        except ValueError:
             raise exceptions.InvalidParameterValueError(
                 parameter='state', value=state,
-                valid_values=list(res_maps.INDICATOR_LED_VALUE_MAP_REV))
+                valid_values=' ,'.join(i.value for i in res_cons.IndicatorLED))
 
-        data = {
-            'IndicatorLED': res_maps.INDICATOR_LED_VALUE_MAP_REV[state]
-        }
+        data = {'IndicatorLED': state}
 
         self._conn.patch(self.path, data=data)
         self.invalidate()
@@ -238,7 +234,9 @@ class Chassis(base.ResourceBase):
             self, ["Links", "ManagedBy"], is_collection=True)
 
         return [manager.Manager(self._conn, path,
-                                self.redfish_version, self.registries)
+                                redfish_version=self.redfish_version,
+                                registries=self.registries,
+                                root=self.root)
                 for path in paths]
 
     @property
@@ -257,7 +255,9 @@ class Chassis(base.ResourceBase):
 
         from sushy.resources.system import system
         return [system.System(self._conn, path,
-                              self.redfish_version, self.registries)
+                              redfish_version=self.redfish_version,
+                              registries=self.registries,
+                              root=self.root)
                 for path in paths]
 
     @property
@@ -272,7 +272,8 @@ class Chassis(base.ResourceBase):
         return power.Power(
             self._conn,
             utils.get_sub_resource_path_by(self, 'Power'),
-            self.redfish_version, self.registries)
+            redfish_version=self.redfish_version, registries=self.registries,
+            root=self.root)
 
     @property
     @utils.cache_it
@@ -286,7 +287,23 @@ class Chassis(base.ResourceBase):
         return thermal.Thermal(
             self._conn,
             utils.get_sub_resource_path_by(self, 'Thermal'),
-            self.redfish_version, self.registries)
+            redfish_version=self.redfish_version, registries=self.registries,
+            root=self.root)
+
+    @property
+    @utils.cache_it
+    def network_adapters(self):
+        """Property to reference `NetworkAdapterCollection` instance
+
+        It is set once when the first time it is queried. On refresh,
+        this property is marked as stale (greedy-refresh not done).
+        Here the actual refresh of the sub-resource happens, if stale.
+        """
+        return adapter.NetworkAdapterCollection(
+            self._conn,
+            utils.get_sub_resource_path_by(self, "NetworkAdapters"),
+            redfish_version=self.redfish_version,
+            registries=self.registries, root=self.root)
 
 
 class ChassisCollection(base.ResourceCollectionBase):
@@ -295,7 +312,8 @@ class ChassisCollection(base.ResourceCollectionBase):
     def _resource_type(self):
         return Chassis
 
-    def __init__(self, connector, path, redfish_version=None, registries=None):
+    def __init__(self, connector, path, redfish_version=None, registries=None,
+                 root=None):
         """A class representing a ChassisCollection
 
         :param connector: A Connector instance
@@ -304,6 +322,8 @@ class ChassisCollection(base.ResourceCollectionBase):
             the object according to schema of the given version.
         :param registries: Dict of Redfish Message Registry objects to be
             used in any resource that needs registries to parse messages
+        :param root: Sushy root object. Empty for Sushy root itself.
         """
         super(ChassisCollection, self).__init__(
-            connector, path, redfish_version, registries)
+            connector, path, redfish_version=redfish_version,
+            registries=registries, root=root)
